@@ -51,6 +51,7 @@ class TelegramError(Exception):
 
         msg = _lstrip_str(message, 'Error: ')
         msg = _lstrip_str(msg, '[Error]: ')
+        msg = _lstrip_str(msg, 'Bad Request: ')
         if msg != message:
             # api_error - capitalize the msg...
             msg = msg.capitalize()
@@ -76,6 +77,10 @@ class NetworkError(TelegramError):
     pass
 
 
+class BadRequest(NetworkError):
+    pass
+
+
 class TimedOut(NetworkError):
 
     def __init__(self):
